// This file is generated by kconfig_compiler_kf6 from keditbookmarks.kcfg.
// All changes you do to this file will be lost.

#include "settings.h"

#include <qglobal.h>
#include <QFile>

class KEBSettingsHelper
{
  public:
    KEBSettingsHelper() noexcept : q(nullptr) {}
    ~KEBSettingsHelper() noexcept { delete q; q = nullptr; }
    KEBSettingsHelper(const KEBSettingsHelper&) = delete;
    KEBSettingsHelper& operator=(const KEBSettingsHelper&) = delete;
    KEBSettings *q;
};
Q_GLOBAL_STATIC(KEBSettingsHelper, s_globalKEBSettings)
KEBSettings *KEBSettings::self()
{
  if (!s_globalKEBSettings()->q) {
    new KEBSettings;
    s_globalKEBSettings()->q->read();
  }

  return s_globalKEBSettings()->q;
}

KEBSettings::KEBSettings( )
  : KConfigSkeleton( QStringLiteral( "keditbookmarksrc" ) )
{
  Q_ASSERT(!s_globalKEBSettings()->q);
  s_globalKEBSettings()->q = this;
  setCurrentGroup( QStringLiteral( "Columns" ) );

  KConfigSkeleton::ItemInt  *itemName;
  itemName = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "Name" ), mName, 300 );
  addItem( itemName, QStringLiteral( "Name" ) );
  KConfigSkeleton::ItemInt  *itemURL;
  itemURL = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "URL" ), mURL, 300 );
  addItem( itemURL, QStringLiteral( "URL" ) );
  KConfigSkeleton::ItemInt  *itemComment;
  itemComment = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "Comment" ), mComment, 300 );
  addItem( itemComment, QStringLiteral( "Comment" ) );
  KConfigSkeleton::ItemInt  *itemStatus;
  itemStatus = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "Status" ), mStatus, 300 );
  addItem( itemStatus, QStringLiteral( "Status" ) );
  KConfigSkeleton::ItemInt  *itemAddress;
  itemAddress = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "Address" ), mAddress, 300 );
  addItem( itemAddress, QStringLiteral( "Address" ) );

  setCurrentGroup( QStringLiteral( "General" ) );

  KConfigSkeleton::ItemBool  *itemSaveOnClose;
  itemSaveOnClose = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "Save On Close" ), mSaveOnClose );
  addItem( itemSaveOnClose, QStringLiteral( "SaveOnClose" ) );
}

KEBSettings::~KEBSettings()
{
  if (s_globalKEBSettings.exists() && !s_globalKEBSettings.isDestroyed()) {
    s_globalKEBSettings()->q = nullptr;
  }
}

