/****************************************************************************
** Meta object code from reading C++ file 'actionsimpl.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../keditbookmarks-26.08.0/src/actionsimpl.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'actionsimpl.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11ActionsImplE_t {};
} // unnamed namespace

template <> constexpr inline auto ActionsImpl::qt_create_metaobjectdata<qt_meta_tag_ZN11ActionsImplE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ActionsImpl",
        "slotLoad",
        "",
        "slotSaveAs",
        "slotCut",
        "slotCopy",
        "slotPaste",
        "slotRename",
        "slotChangeURL",
        "slotChangeComment",
        "slotChangeIcon",
        "slotDelete",
        "slotNewFolder",
        "slotNewBookmark",
        "slotInsertSeparator",
        "slotSort",
        "slotSetAsToolbar",
        "slotOpenLink",
        "slotTestSelection",
        "slotTestAll",
        "slotCancelAllTests",
        "slotUpdateFavIcon",
        "slotRecursiveSort",
        "slotUpdateAllFavIcons",
        "slotCancelFavIconUpdates",
        "slotExpandAll",
        "slotCollapseAll",
        "slotImport",
        "slotExportOpera",
        "slotExportHTML",
        "slotExportIE",
        "slotExportNS",
        "slotExportMoz"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotLoad'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSaveAs'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCut'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCopy'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPaste'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRename'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotChangeURL'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotChangeComment'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotChangeIcon'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDelete'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNewFolder'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNewBookmark'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotInsertSeparator'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSort'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSetAsToolbar'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotOpenLink'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotTestSelection'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotTestAll'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCancelAllTests'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotUpdateFavIcon'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRecursiveSort'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotUpdateAllFavIcons'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCancelFavIconUpdates'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotExpandAll'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCollapseAll'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotImport'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotExportOpera'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotExportHTML'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotExportIE'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotExportNS'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotExportMoz'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ActionsImpl, qt_meta_tag_ZN11ActionsImplE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ActionsImpl::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ActionsImplE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ActionsImplE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11ActionsImplE_t>.metaTypes,
    nullptr
} };

void ActionsImpl::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ActionsImpl *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotLoad(); break;
        case 1: _t->slotSaveAs(); break;
        case 2: _t->slotCut(); break;
        case 3: _t->slotCopy(); break;
        case 4: _t->slotPaste(); break;
        case 5: _t->slotRename(); break;
        case 6: _t->slotChangeURL(); break;
        case 7: _t->slotChangeComment(); break;
        case 8: _t->slotChangeIcon(); break;
        case 9: _t->slotDelete(); break;
        case 10: _t->slotNewFolder(); break;
        case 11: _t->slotNewBookmark(); break;
        case 12: _t->slotInsertSeparator(); break;
        case 13: _t->slotSort(); break;
        case 14: _t->slotSetAsToolbar(); break;
        case 15: _t->slotOpenLink(); break;
        case 16: _t->slotTestSelection(); break;
        case 17: _t->slotTestAll(); break;
        case 18: _t->slotCancelAllTests(); break;
        case 19: _t->slotUpdateFavIcon(); break;
        case 20: _t->slotRecursiveSort(); break;
        case 21: _t->slotUpdateAllFavIcons(); break;
        case 22: _t->slotCancelFavIconUpdates(); break;
        case 23: _t->slotExpandAll(); break;
        case 24: _t->slotCollapseAll(); break;
        case 25: _t->slotImport(); break;
        case 26: _t->slotExportOpera(); break;
        case 27: _t->slotExportHTML(); break;
        case 28: _t->slotExportIE(); break;
        case 29: _t->slotExportNS(); break;
        case 30: _t->slotExportMoz(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *ActionsImpl::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ActionsImpl::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ActionsImplE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ActionsImpl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 31)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 31;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 31)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 31;
    }
    return _id;
}
QT_WARNING_POP
